@@ -1,4 +1,4 @@
-# Copyright (C) 2002-2021 Free Software Foundation, Inc.
+# Copyright (C) 2002-2014 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
 # GNU General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 ###############################################################
 # The main copy of this file is in Automake's git repository. #
@@ -68,25 +68,24 @@ etc.) that can also be overridden on a per-message basis.
 
 use 5.006;
 use strict;
-use warnings FATAL => 'all';
-
-use Carp;
 use Exporter;
+use Carp;
 use File::Basename;
 
-our @ISA = qw (Exporter);
-our @EXPORT = qw ($exit_code $warnings_are_errors
-		  &reset_local_duplicates &reset_global_duplicates
-		  &register_channel &msg &exists_channel &channel_type
-		  &setup_channel &setup_channel_type
-		  &dup_channel_setup &drop_channel_setup
-		  &buffer_messages &flush_messages
-		  &setup_channel_queue &pop_channel_queue
-		  US_GLOBAL US_LOCAL
-		  UP_NONE UP_TEXT UP_LOC_TEXT);
+use vars qw (@ISA @EXPORT %channels $me);
 
-our %channels;
-our $me = basename $0;
+@ISA = qw (Exporter);
+@EXPORT = qw ($exit_code $warnings_are_errors
+	      &reset_local_duplicates &reset_global_duplicates
+	      &register_channel &msg &exists_channel &channel_type
+	      &setup_channel &setup_channel_type
+	      &dup_channel_setup &drop_channel_setup
+	      &buffer_messages &flush_messages
+	      &setup_channel_queue &pop_channel_queue
+	      US_GLOBAL US_LOCAL
+	      UP_NONE UP_TEXT UP_LOC_TEXT);
+
+$me = basename $0;
 
 =head2 Global Variables
 
@@ -99,7 +98,8 @@ the C<exit_code> options of C<fatal> and C<error> channels.
 
 =cut
 
-our $exit_code = 0;
+use vars qw ($exit_code);
+$exit_code = 0;
 
 =item C<$warnings_are_errors>
 
@@ -108,7 +108,8 @@ errors (i.e. if they should update C<$exit_code>).
 
 =cut
 
-our $warnings_are_errors = 0;
+use vars qw ($warnings_are_errors);
+$warnings_are_errors = 0;
 
 =back
 
@@ -258,8 +259,11 @@ be ignored.
 
 =cut
 
+use vars qw (%_default_options %_global_duplicate_messages
+	     %_local_duplicate_messages);
+
 # Default options for a channel.
-our %_default_options =
+%_default_options =
   (
    type => 'warning',
    exit_code => 1,
@@ -279,8 +283,8 @@ our %_default_options =
 # Filled with output messages as keys, to detect duplicates.
 # The value associated with each key is the number of occurrences
 # filtered out.
-our %_local_duplicate_messages = ();
-our %_global_duplicate_messages = ();
+%_local_duplicate_messages = ();
+%_global_duplicate_messages = ();
 
 sub _reset_duplicates (\%)
 {
@@ -399,7 +403,8 @@ sub _format_sub_message ($$)
 }
 
 # Store partial messages here. (See the 'partial' option.)
-our $partial = '';
+use vars qw ($partial);
+$partial = '';
 
 # _format_message ($LOCATION, $MESSAGE, %OPTIONS)
 # -----------------------------------------------
@@ -614,9 +619,11 @@ both print
 =cut
 
 
+use vars qw (@backlog %buffering);
+
 # See buffer_messages() and flush_messages() below.
-our %buffering = ();	# The map of channel types to buffer.
-our @backlog = ();		# The buffer of messages.
+%buffering = ();	# The map of channel types to buffer.
+@backlog = ();		# The buffer of messages.
 
 sub msg ($$;$%)
 {
@@ -708,8 +715,9 @@ entry, while C<drop_channel_setup ()> just deletes it.
 
 =cut
 
-our @_saved_channels = ();
-our @_saved_werrors = ();
+use vars qw (@_saved_channels @_saved_werrors);
+@_saved_channels = ();
+@_saved_werrors = ();
 
 sub dup_channel_setup ()
 {
@@ -809,3 +817,20 @@ Written by Alexandre Duret-Lutz E<lt>F<adl@gnu.org>E<gt>.
 =cut
 
 1;
+
+### Setup "GNU" style for perl-mode and cperl-mode.
+## Local Variables:
+## perl-indent-level: 2
+## perl-continued-statement-offset: 2
+## perl-continued-brace-offset: 0
+## perl-brace-offset: 0
+## perl-brace-imaginary-offset: 0
+## perl-label-offset: -2
+## cperl-indent-level: 2
+## cperl-brace-offset: 0
+## cperl-continued-brace-offset: 0
+## cperl-label-offset: -2
+## cperl-extra-newline-before-brace: t
+## cperl-merge-trailing-else: nil
+## cperl-continued-statement-offset: 2
+## End:
