@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2010-2012 Free Software Foundation, Inc.
+# Copyright (C) 2010-2014 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 
 # Test to make sure all-local and other -local targets work correctly.
 
-. ./defs || Exit 1
+. test-init.sh
 
 $ACLOCAL
 
@@ -25,7 +25,7 @@ for target in $targets; do
   : Doing $target
   echo "${target}-local:" > Makefile.am
   $AUTOMAKE
-  grep "${target}-local ${target}-local" Makefile.in && Exit 1
+  grep "${target}-local ${target}-local" Makefile.in && exit 1
   grep "${target}-am:.*${target}-local" Makefile.in
 done
 
