@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2011-2013 Free Software Foundation, Inc.
+# Copyright (C) 2011-2014 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -74,7 +74,7 @@ $AUTOCONF
 $AUTOMAKE
 ./configure
 
-unset CLASSPATH || :
+unset CLASSPATH
 $MAKE
 $MAKE clean
 
@@ -82,7 +82,7 @@ CLASSPATH=''; export CLASSPATH
 $MAKE
 $MAKE clean
 
-unset CLASSPATH || :
+unset CLASSPATH
 $MAKE distcheck
 
 :
